@@ -1,12 +1,12 @@
-# $Id: en_us.pm 507 2005-06-08 03:17:04Z claco $
+# $Id: en_us.pm 1335 2006-07-15 02:43:12Z claco $
 package Handel::L10N::en_us;
 use strict;
 use warnings;
 use utf8;
-use vars qw(%Lexicon);
+use vars qw/%Lexicon/;
 
 BEGIN {
-    use base 'Handel::L10N';
+    use base qw/Handel::L10N/;
 };
 
 %Lexicon = (
@@ -25,4 +25,4 @@ Handel::L10N::en_us - Handel Language Pack: US English
     Christopher H. Laco
     CPAN ID: CLACO
     claco@chrislaco.com
-    http://today.icantfocus.com/blog/
\ No newline at end of file
+    http://today.icantfocus.com/blog/
